netapp_ontap.models.application_statistics_latency API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.application_statistics_latency`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationStatisticsLatencySchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationStatisticsLatency object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `average GET`

    The cumulative average response time in microseconds for this component.

  `raw GET`

    The cumulative response time in microseconds for this component.